==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/Effect/bs2b/translations/bs2b_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_BA">
<context>
    <name>EffectBs2bFactory</name>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="31"/>
        <source>BS2B Plugin</source>
        <translation>БС2Б прикључак</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="51"/>
        <source>About BS2B Effect Plugin</source>
        <translation>О прикључку за БС2Б ефекат</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="52"/>
        <source>This is the Qmmp plugin version of Boris Mikhaylov&apos;s headphone DSP effect &quot;Bauer stereophonic-to-binaural&quot;, abbreviated bs2b.</source>
        <translation>Кумп издање прикључка ДСП ефекта за слушалице „Бауерово стереофонски-на-бинаурално“ Бориса Михајлова, скраћено бс2б.</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="54"/>
        <source>Visit %1 for more details</source>
        <translation>Посјетите %1 за више детаља</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="56"/>
        <source>Compiled against libbs2b-%1</source>
        <translation>Компилован на libbs2b-%1</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="57"/>
        <source>Developers:</source>
        <translation>Програмери:</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="58"/>
        <source>Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="59"/>
        <source>Sebastian Pipping &amp;lt;sebastian@pipping.org&amp;gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>BS2B Plugin Settings</source>
        <translation>Поставке БС2Б прикључка</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <source>Crossfeed level</source>
        <translation>Ниво међуукрштања канала</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Default</source>
        <translation>Подразумијевано</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>C.Moy</source>
        <translation>C.Moy</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>J. Meier</source>
        <translation>J. Meier</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="60"/>
        <source>%1 Hz, %2 us</source>
        <translation>%1 Hz, %2 us</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="67"/>
        <source>%1 dB</source>
        <translation>%1 dB</translation>
    </message>
</context>
</TS>

==> qmmp_2.2.2.orig.tar.bz2: qmmp-2.2.2/src/plugins/Effect/bs2b/translations/bs2b_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_BA">
<context>
    <name>Bs2bSettingsDialog</name>
    <message>
        <location filename="../bs2bsettingsdialog.ui" line="14"/>
        <source>BS2B Plugin Settings</source>
        <translation type="unfinished">Поставке БС2Б прикључка</translation>
    </message>
    <message>
        <location filename="../bs2bsettingsdialog.ui" line="32"/>
        <source>Crossfeed level</source>
        <translation type="unfinished">Ниво међуукрштања канала</translation>
    </message>
    <message>
        <location filename="../bs2bsettingsdialog.ui" line="45"/>
        <location filename="../bs2bsettingsdialog.ui" line="59"/>
        <source>-</source>
        <translation type="unfinished">-</translation>
    </message>
    <message>
        <location filename="../bs2bsettingsdialog.ui" line="71"/>
        <source>Default</source>
        <translation type="unfinished">Подразумијевано</translation>
    </message>
    <message>
        <location filename="../bs2bsettingsdialog.ui" line="78"/>
        <source>C.Moy</source>
        <translation type="unfinished">C.Moy</translation>
    </message>
    <message>
        <location filename="../bs2bsettingsdialog.ui" line="85"/>
        <source>J. Meier</source>
        <translation type="unfinished">J. Meier</translation>
    </message>
    <message>
        <location filename="../bs2bsettingsdialog.cpp" line="61"/>
        <source>%1 Hz, %2 us</source>
        <translation type="unfinished">%1 Hz, %2 us</translation>
    </message>
    <message>
        <location filename="../bs2bsettingsdialog.cpp" line="68"/>
        <source>%1 dB</source>
        <translation type="unfinished">%1 dB</translation>
    </message>
</context>
<context>
    <name>EffectBs2bFactory</name>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="31"/>
        <source>BS2B Plugin</source>
        <translation>БС2Б прикључак</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="50"/>
        <source>About BS2B Effect Plugin</source>
        <translation>О прикључку за БС2Б ефекат</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="52"/>
        <source>This is the Qmmp plugin version of Boris Mikhaylov&apos;s headphone DSP effect &quot;Bauer stereophonic-to-binaural&quot;, abbreviated bs2b.</source>
        <translation>Кумп издање прикључка ДСП ефекта за слушалице „Бауерово стереофонски-на-бинаурално“ Бориса Михајлова, скраћено бс2б.</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="55"/>
        <source>Visit %1 for more details</source>
        <translation>Посјетите %1 за више детаља</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="57"/>
        <source>Compiled against libbs2b-%1</source>
        <translation>Компилован на libbs2b-%1</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="59"/>
        <source>Developers:</source>
        <translation>Програмери:</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="60"/>
        <source>Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="61"/>
        <source>Sebastian Pipping &amp;lt;sebastian@pipping.org&amp;gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
